<?php
namespace BWDMVMaskingVideo;

use BWDMVMaskingVideo\PageSettings\Page_Settings;
define( "BWDMV_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDMV_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class ClassBWDMVMaskingVideo {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdmv_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdmv_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdmv_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdmv_the_masking_video_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdmv-masking-video.php' );
	}

	
	public function bwdmv_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDMVMaskingVideoWidget() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/masking-video-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdmv_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdmv-masking-video-category',
			[
				'title' => esc_html__( 'BWD Masking Video', 'bwdmv-masking-video' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdmv_all_assets_for_the_public(){
		wp_enqueue_style( 'Font_Awesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.9.0/css/all.min.css', array(),'5.9.0','all');

		wp_enqueue_script( 'bwdmv_masking_video_custom_js', plugin_dir_url( __FILE__ ) . 'assets/public/js/custom.js', array('jquery'), '1.0', true );

		$all_css_js_file = array(
            'bwdmv_masking_video_main_css' => array('bwdmv_path_define'=>BWDMV_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),
        );
		
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdmv_path_define'], null, '1.0', 'all');
        }
	}
	public function bwdmv_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdmv_masking_video_admin_icon_css' => array('bwdmv_path_admin_define'=>BWDMV_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdmv_path_admin_define'], null, '1.0', 'all');
        }
	}
	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdmv_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdmv_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdmv_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdmv_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdmv_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDMVMaskingVideo::instance();